==> apache-storm-2.3.0-src.tar.gz: apache-storm-2.3.0/storm-server/src/test/java/org/apache/storm/utils/ZookeeperServerCnxnFactoryTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.utils;

import org.junit.Assert;
import org.junit.Test;

public class ZookeeperServerCnxnFactoryTest {

    @Test(expected = RuntimeException.class)
    public void test_Exception_In_Constructor_If_Port_Too_Large() {
        new ZookeeperServerCnxnFactory(65536, 42);
    }

    @Test
    public void testFactory() {
        int arbitraryTestClients = 42;
        ZookeeperServerCnxnFactory zkcfNegative = new ZookeeperServerCnxnFactory(-42, arbitraryTestClients);
        int nextPort = zkcfNegative.port() + 1;
        ZookeeperServerCnxnFactory zkcfNext = new ZookeeperServerCnxnFactory(nextPort, arbitraryTestClients);
        Assert.assertEquals(zkcfNext.factory().getMaxClientCnxnsPerHost(), arbitraryTestClients);
    }
}

==> apache-storm-2.6.2-src.tar.gz: apache-storm-2.6.2/storm-server/src/test/java/org/apache/storm/utils/ZookeeperServerCnxnFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.utils;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertThrows;

public class ZookeeperServerCnxnFactoryTest {

    @Test
    public void test_Exception_In_Constructor_If_Port_Too_Large() {
        assertThrows(RuntimeException.class, () -> new ZookeeperServerCnxnFactory(65536, 42));
    }

    @Test
    public void testFactory() {
        int arbitraryTestClients = 42;
        ZookeeperServerCnxnFactory zkcfNegative = new ZookeeperServerCnxnFactory(-42, arbitraryTestClients);
        int nextPort = zkcfNegative.port() + 1;
        ZookeeperServerCnxnFactory zkcfNext = new ZookeeperServerCnxnFactory(nextPort, arbitraryTestClients);
        assertEquals(zkcfNext.factory().getMaxClientCnxnsPerHost(), arbitraryTestClients);
    }
}
